@@ -1,6 +1,6 @@
 /*
    This file is part of the BOLT-LMM linear mixed model software package
-   developed by Po-Ru Loh.  Copyright (C) 2014-2019 Harvard University.
+   developed by Po-Ru Loh.  Copyright (C) 2014-2021 Harvard University.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -54,13 +54,13 @@ int main(int argc, char *argv[]) {
 
   cout << "                      +-----------------------------+" << endl;
   cout << "                      |                       ___   |" << endl;
-  cout << "                      |   BOLT-LMM, v2.3.4   /_ /   |" << endl;
-  cout << "                      |   August 10, 2019     /_/   |" << endl;
+  cout << "                      |   BOLT-LMM, v2.3.6   /_ /   |" << endl;
+  cout << "                      |   October 29, 2021    /_/   |" << endl;
   cout << "                      |   Po-Ru Loh            //   |" << endl;
   cout << "                      |                        /    |" << endl;
   cout << "                      +-----------------------------+" << endl;
   cout << endl;
-  cout << "Copyright (C) 2014-2019 Harvard University." << endl;
+  cout << "Copyright (C) 2014-2021 Harvard University." << endl;
   cout << "Distributed under the GNU GPLv3 open source license." << endl << endl;
 
 #ifdef VERBOSE
@@ -153,7 +153,10 @@ int main(int argc, char *argv[]) {
 
   cout << "=== Reading phenotype and covariate data ===" << endl << endl;
 
-  DataMatrix covarDataT(params.covarFile, snpData);
+  vector <string> covarColNames;
+  for (uint i = 0; i < params.covarCols.size(); i++)
+    covarColNames.push_back(params.covarCols[i].first);
+  DataMatrix covarDataT(params.covarFile, snpData, covarColNames);
 
   vector <double> maskIndivs(snpData.getNstride());
   snpData.writeMaskIndivs(&maskIndivs[0]);
@@ -162,7 +165,7 @@ int main(int argc, char *argv[]) {
   vector < vector <double> > phenoVecs; double phenoMissingKey = -9;
   if (!params.phenoFile.empty()) { // phenotypes provided in file
     phenoVecs.resize(params.phenoCols.size());
-    DataMatrix phenoDataT(params.phenoFile, snpData);
+    DataMatrix phenoDataT(params.phenoFile, snpData, params.phenoCols);
     for (uint p = 0; p < phenoVecs.size(); p++) {
       const string &phenoCol = params.phenoCols[p];
       phenoVecs[p] = phenoDataT.getRowDbl(phenoCol); // assign pheno from column of file
