@@ -1,6 +1,6 @@
 /*
    This file is part of the BOLT-LMM linear mixed model software package
-   developed by Po-Ru Loh.  Copyright (C) 2014-2019 Harvard University.
+   developed by Po-Ru Loh.  Copyright (C) 2014-2021 Harvard University.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -475,6 +475,10 @@ namespace LMM {
 	cerr << "ERROR: --statsFile must be specified for association output" << endl;
 	return false;
       }
+      if (vm.count("predBetasFile") && !lmmInf) {
+	cerr << "ERROR: --predBetasFile requires specifying one of the --lmm* options" << endl;
+	return false;
+      }
       if (lmmBayes || lmmBayesMCMC) {
 	if (LDscoresUseChip) {
 	  //if (!LDscoresCol.empty())
