@@ -1,6 +1,6 @@
 /*
    This file is part of the BOLT-LMM linear mixed model software package
-   developed by Po-Ru Loh.  Copyright (C) 2014-2019 Harvard University.
+   developed by Po-Ru Loh.  Copyright (C) 2014-2021 Harvard University.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -255,16 +255,6 @@ namespace FileUtils {
     return !boost_out.fail();
   }
 
-  int chrStrToInt(const string &chrom, int Nauto) {
-    if (isdigit(chrom[0])) {
-      int chr = atoi(chrom.c_str());
-      if (chr>=1 && chr<=Nauto+1) return chr;
-      return -1;
-    }
-    if (chrom == "X" || chrom == "XY" || chrom == "PAR1" || chrom == "PAR2") return Nauto+1;
-    return -1;
-  }
-
   int checkBgenSample(const std::string &bgenFile, const std::string &sampleFile, int Nautosomes) {
     uint Nsample = FileUtils::readSampleIDs(sampleFile).size();
 
@@ -313,7 +303,7 @@ namespace FileUtils {
       ushort LC; fread(&LC, 2, 1, fin); // cout << "LC: " << LC << " " << std::flush;
       fread(chrStr, 1, LC, fin); chrStr[LC] = '\0';
 
-      int chrom = chrStrToInt(chrStr, Nautosomes);
+      int chrom = LMM::SnpData::chrStrToInt(chrStr, Nautosomes);
       if (chrom == -1) {
 	cerr << "ERROR: Invalid chrom (expecting integer 1-" << Nautosomes+1
 	     << " or X,XY,PAR1,PAR2): " << string(chrStr) << endl;
