@@ -1,6 +1,6 @@
 /*
    This file is part of the BOLT-LMM linear mixed model software package
-   developed by Po-Ru Loh.  Copyright (C) 2014-2019 Harvard University.
+   developed by Po-Ru Loh.  Copyright (C) 2014-2021 Harvard University.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -49,7 +49,9 @@ namespace LMM {
 
   const uint64 SnpData::IND_MISSING = (uint64) -1;
 
-  int SnpData::chrStrToInt(const string &chrom, int Nauto) {
+  int SnpData::chrStrToInt(string chrom, int Nauto) {
+    if (chrom.substr(0, 3) == "chr")
+      chrom = chrom.substr(3);
     if (isdigit(chrom[0])) {
       int chr = atoi(chrom.c_str());
       if (chr>=1 && chr<=Nauto+1) return chr;
